@@ -1,11 +1,10 @@
-use pyo3::prelude::*;
+use pyo3::{exceptions::PyValueError, prelude::*};
 
 pub struct RegexError(regex::Error);
-pub type RegexResult<T> = Result<T, RegexError>;
 
 impl From<RegexError> for PyErr {
     fn from(value: RegexError) -> Self {
-        PyErr::new::<pyo3::types::PyString, _>(value.0.to_string())
+        PyValueError::new_err(value.0.to_string())
     }
 }
 
